@@ -1,14 +1,18 @@
+DEFINE_TEST(test_0)
 DEFINE_TEST(test_basic)
+DEFINE_TEST(test_cmdline)
 DEFINE_TEST(test_format_newc)
 DEFINE_TEST(test_gcpio_compat)
-DEFINE_TEST(test_option_B)
-DEFINE_TEST(test_option_L)
+DEFINE_TEST(test_option_B_upper)
+DEFINE_TEST(test_option_C_upper)
+DEFINE_TEST(test_option_L_upper)
+DEFINE_TEST(test_option_Z_upper)
 DEFINE_TEST(test_option_a)
 DEFINE_TEST(test_option_c)
 DEFINE_TEST(test_option_d)
-DEFINE_TEST(test_option_ell)
 DEFINE_TEST(test_option_f)
 DEFINE_TEST(test_option_help)
+DEFINE_TEST(test_option_l)
 DEFINE_TEST(test_option_m)
 DEFINE_TEST(test_option_t)
 DEFINE_TEST(test_option_u)
@@ -16,4 +20,6 @@ DEFINE_TEST(test_option_version)
 DEFINE_TEST(test_option_y)
 DEFINE_TEST(test_option_z)
 DEFINE_TEST(test_owner_parse)
+DEFINE_TEST(test_passthrough_dotdot)
+DEFINE_TEST(test_passthrough_reverse)
 DEFINE_TEST(test_pathmatch)
