@@ -43,8 +43,10 @@ archive_read_support_format_empty(struct archive *_a)
 	int r;
 
 	r = __archive_read_register_format(a,
+	    NULL,
 	    NULL,
 	    archive_read_format_empty_bid,
+	    NULL,
 	    archive_read_format_empty_read_header,
 	    archive_read_format_empty_read_data,
 	    NULL,
@@ -58,9 +60,10 @@ static int
 archive_read_format_empty_bid(struct archive_read *a)
 {
 	const void *h;
+	ssize_t avail;
 
-	h = __archive_read_ahead(a, 1, NULL);
-	if (h != NULL)
+	h = __archive_read_ahead(a, 1, &avail);
+	if (avail != 0)
 		return (-1);
 	return (1);
 }
