@@ -18,9 +18,7 @@ DEFINE_TEST(test_link_resolver)
 DEFINE_TEST(test_open_fd)
 DEFINE_TEST(test_open_file)
 DEFINE_TEST(test_open_filename)
-DEFINE_TEST(test_pax_filename_encoding_1)
-DEFINE_TEST(test_pax_filename_encoding_2)
-DEFINE_TEST(test_pax_filename_encoding_3)
+DEFINE_TEST(test_pax_filename_encoding)
 DEFINE_TEST(test_read_compress_program)
 DEFINE_TEST(test_read_data_large)
 DEFINE_TEST(test_read_disk)
