@@ -28,11 +28,11 @@ __FBSDID("$FreeBSD: src/lib/libarchive/test/test_read_format_mtree.c,v 1.4 2008/
 /* Single entry with a hardlink. */
 static unsigned char archive[] = {
 	"#mtree\n"
-	"file type=file uid=18 mode=0123\n"
+	"file type=file uid=18 mode=0123 size=3\n"
 	"dir type=dir\n"
 	" file\\040with\\040space type=file uid=18\n"
 	" ..\n"
-	"file\\04with\\040space type=file\n"
+	"file\\040with\\040space type=file\n"
 	"dir2 type=dir\n"
 	" dir3a type=dir\n"
 	"  indir3a type=file\n"
@@ -49,8 +49,10 @@ static unsigned char archive[] = {
 
 DEFINE_TEST(test_read_format_mtree)
 {
+	char buff[16];
 	struct archive_entry *ae;
 	struct archive *a;
+	int fd;
 
 	/*
 	 * An access error occurred on some platform when mtree
@@ -68,12 +70,23 @@ DEFINE_TEST(test_read_format_mtree)
 	    archive_read_support_format_all(a));
 	assertEqualIntA(a, ARCHIVE_OK,
 	    archive_read_open_memory(a, archive, sizeof(archive)));
+
+	/*
+	 * Read "file", whose data is available on disk.
+	 */
+	fd = open("file", O_WRONLY | O_CREAT, 0777);
+	assert(fd >= 0);
+	assertEqualInt(3, write(fd, "hi\n", 3));
+	close(fd);
 	assertEqualIntA(a, ARCHIVE_OK, archive_read_next_header(a, &ae));
 	assertEqualInt(archive_format(a), ARCHIVE_FORMAT_MTREE);
 	assertEqualString(archive_entry_pathname(ae), "file");
 	assertEqualInt(archive_entry_uid(ae), 18);
 	assert(S_ISREG(archive_entry_mode(ae)));
 	assertEqualInt(archive_entry_mode(ae), AE_IFREG | 0123);
+	assertEqualInt(archive_entry_size(ae), 3);
+	assertEqualInt(3, archive_read_data(a, buff, 3));
+	assertEqualMem(buff, "hi\n", 3);
 
 	assertEqualIntA(a, ARCHIVE_OK, archive_read_next_header(a, &ae));
 	assertEqualString(archive_entry_pathname(ae), "dir");
@@ -83,7 +96,7 @@ DEFINE_TEST(test_read_format_mtree)
 	assertEqualString(archive_entry_pathname(ae), "dir/file with space");
 
 	assertEqualIntA(a, ARCHIVE_OK, archive_read_next_header(a, &ae));
-	assertEqualString(archive_entry_pathname(ae), "file\\04with space");
+	assertEqualString(archive_entry_pathname(ae), "file with space");
 
 	assertEqualIntA(a, ARCHIVE_OK, archive_read_next_header(a, &ae));
 	assertEqualString(archive_entry_pathname(ae), "dir2");
